==> math-3.0.3.jar: hara/math/stats.clj <==
(ns hara.math.stats
  (:require [hara.module :as module]))

(module/include
 (hara.math.stats.distribution         random-sample
                                       probability
                                       cumulative
                                       
                                       ;; -- distributions --
                                       
                                       ansari
                                       arcsine
                                       beta
                                       beta-binomial
                                       beta-prime
                                       binomial
                                       cauchy
                                       chi
                                       chi-square
                                       exponential
                                       extreme
                                       f
                                       fretchet
                                       gamma
                                       generalized-pareto
                                       geometric
                                       gev
                                       gumbel
                                       hyper-geometric
                                       inv-gamma
                                       inv-normal
                                       kendall
                                       kumaraswamy
                                       laplace
                                       levy
                                       log-normal
                                       logarithmic
                                       logistic
                                       nakagami
                                       neg-binomial
                                       non-central-beta
                                       non-central-chi-square
                                       non-central-f
                                       non-central-t
                                       normal
                                       order
                                       poisson
                                       rayleigh
                                       reverse-weibull
                                       sign-rank
                                       skewed-t
                                       spearman
                                       t
                                       tukey
                                       uniform
                                       weibull
                                       wilcoxon
                                       zipf)

 (hara.math.stats.normality            anderson-darling
                                       cramer-vonmises
                                       jarque-bera
                                       kolmogorov-lilliefors
                                       kolmogorov-smirnov
                                       shapiro-francia
                                       shapiro-wilk))

==> math-3.0.12.jar: hara/math/stats.clj <==
(ns hara.math.stats
  (:require [hara.module :as module]
            [hara.math.stats.distribution :as distribution]
            [hara.math.stats.normality :as normality]))

(module/include
 (hara.math.stats.distribution         random-sample
                                       probability
                                       cumulative
                                       
                                       ;; -- distributions --
                                       
                                       ansari
                                       arcsine
                                       beta
                                       beta-binomial
                                       beta-prime
                                       binomial
                                       cauchy
                                       chi
                                       chi-square
                                       exponential
                                       extreme
                                       f
                                       fretchet
                                       gamma
                                       generalized-pareto
                                       geometric
                                       gev
                                       gumbel
                                       hyper-geometric
                                       inv-gamma
                                       inv-normal
                                       kendall
                                       kumaraswamy
                                       laplace
                                       levy
                                       log-normal
                                       logarithmic
                                       logistic
                                       nakagami
                                       neg-binomial
                                       non-central-beta
                                       non-central-chi-square
                                       non-central-f
                                       non-central-t
                                       normal
                                       order
                                       poisson
                                       rayleigh
                                       reverse-weibull
                                       sign-rank
                                       skewed-t
                                       spearman
                                       t
                                       tukey
                                       uniform
                                       weibull
                                       wilcoxon
                                       zipf)

 (hara.math.stats.normality            anderson-darling
                                       cramer-vonmises
                                       jarque-bera
                                       kolmogorov-lilliefors
                                       kolmogorov-smirnov
                                       shapiro-francia
                                       shapiro-wilk))
